@@ -80,7 +80,7 @@ class ARROW_ACERO_EXPORT ExecNodeOptions {
 ///
 /// For each batch received a new task will be created to push that batch downstream.
 /// This task will slice smaller units of size `ExecPlan::kMaxBatchSize` from the
-/// parent batch and call InputRecieved.  Thus, if the `generator` yields a large
+/// parent batch and call InputReceived.  Thus, if the `generator` yields a large
 /// batch it may result in several calls to InputReceived.
 ///
 /// The SourceNode will, by default, assign an implicit ordering to outgoing batches.
@@ -115,7 +115,7 @@ class ARROW_ACERO_EXPORT TableSourceNodeOptions : public ExecNodeOptions {
   /// Create an instance from values
   TableSourceNodeOptions(std::shared_ptr<Table> table,
                          int64_t max_batch_size = kDefaultMaxBatchSize)
-      : table(table), max_batch_size(max_batch_size) {}
+      : table(std::move(table)), max_batch_size(max_batch_size) {}
 
   /// \brief a table which acts as the data source
   std::shared_ptr<Table> table;
@@ -135,7 +135,7 @@ class ARROW_ACERO_EXPORT NamedTableNodeOptions : public ExecNodeOptions {
  public:
   /// Create an instance from values
   NamedTableNodeOptions(std::vector<std::string> names, std::shared_ptr<Schema> schema)
-      : names(std::move(names)), schema(schema) {}
+      : names(std::move(names)), schema(std::move(schema)) {}
 
   /// \brief the names to put in the serialized plan
   std::vector<std::string> names;
@@ -156,7 +156,7 @@ class ARROW_ACERO_EXPORT SchemaSourceNodeOptions : public ExecNodeOptions {
   /// Create an instance that will create a new task on io_executor for each iteration
   SchemaSourceNodeOptions(std::shared_ptr<Schema> schema, ItMaker it_maker,
                           arrow::internal::Executor* io_executor)
-      : schema(schema),
+      : schema(std::move(schema)),
         it_maker(std::move(it_maker)),
         io_executor(io_executor),
         requires_io(true) {}
@@ -165,7 +165,7 @@ class ARROW_ACERO_EXPORT SchemaSourceNodeOptions : public ExecNodeOptions {
   /// executor
   SchemaSourceNodeOptions(std::shared_ptr<Schema> schema, ItMaker it_maker,
                           bool requires_io = false)
-      : schema(schema),
+      : schema(std::move(schema)),
         it_maker(std::move(it_maker)),
         io_executor(NULLPTR),
         requires_io(requires_io) {}
