@@ -15,15 +15,15 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 13
+#define ARROW_VERSION_MAJOR 14
 #define ARROW_VERSION_MINOR 0
 #define ARROW_VERSION_PATCH 0
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "13.0.0"
+#define ARROW_VERSION_STRING "14.0.0"
 
-#define ARROW_SO_VERSION "1300"
-#define ARROW_FULL_SO_VERSION "1300.0.0"
+#define ARROW_SO_VERSION "1400"
+#define ARROW_FULL_SO_VERSION "1400.0.0"
 
 #define ARROW_CXX_COMPILER_ID "Clang"
 #define ARROW_CXX_COMPILER_VERSION "16.0.6"
@@ -51,11 +51,11 @@
 #define ARROW_PARQUET
 #define ARROW_SUBSTRAIT
 
+#define ARROW_ENABLE_THREADING
 /* #undef ARROW_GCS */
 /* #undef ARROW_S3 */
 #define ARROW_USE_NATIVE_INT128
 /* #undef ARROW_WITH_MUSL */
 /* #undef ARROW_WITH_OPENTELEMETRY */
 /* #undef ARROW_WITH_UCX */
-
-#define GRPCPP_PP_INCLUDE
+#define PARQUET_REQUIRE_ENCRYPTION
